@@ -10,10 +10,10 @@ from .tools.macchanger import Macchanger
 
 class Configuration(object):
     ''' Stores configuration variables and functions for Wifite. '''
-    version = '2.5.5'
+    version = '2.5.7'
 
     initialized = False  # Flag indicating config has been initialized
-    temp_dir = None     # Temporary directory
+    temp_dir = None  # Temporary directory
     interface = None
     verbose = 0
 
@@ -96,7 +96,7 @@ class Configuration(object):
         cls.dont_use_pmkid = False  # Don't use PMKID attack
 
         # Default dictionary for cracking
-        cls.cracked_file = 'cracked.txt'
+        cls.cracked_file = 'cracked.json'
         cls.wordlist = None
         wordlists = [
             './wordlist-probable.txt',  # Local file (ran from cloned repo)
@@ -112,8 +112,8 @@ class Configuration(object):
                 cls.wordlist = wlist
                 break
 
-        if os.path.isfile('./usr/share/ieee-data/oui.txt'):
-            manufacturers = './usr/share/ieee-data/oui.txt'
+        if os.path.isfile('/usr/share/ieee-data/oui.txt'):
+            manufacturers = '/usr/share/ieee-data/oui.txt'
         else:
             manufacturers = './ieee-oui.txt'
 
@@ -136,6 +136,7 @@ class Configuration(object):
         cls.use_bully = False  # Use bully instead of reaver
         cls.use_reaver = False  # Use reaver instead of bully
         cls.wps_pixie = True
+        cls.wps_nullpin = True
         cls.wps_pin = True
         cls.wps_ignore_lock = False  # Skip WPS PIN attack if AP is locked.
         cls.wps_pixie_timeout = 300  # Seconds to wait for PIN before WPS Pixie attack fails
@@ -412,6 +413,7 @@ class Configuration(object):
             # No WPS attacks at all
             cls.no_wps = args.no_wps
             cls.wps_pixie = False
+            cls.wps_nullpin = False
             cls.wps_pin = False
             Color.pl('{+} {C}option:{W} will {O}never{W} use {C}WPS attacks{W} ' +
                     '(Pixie-Dust/PIN) on targets')
@@ -419,17 +421,28 @@ class Configuration(object):
         elif args.wps_pixie:
             # WPS Pixie-Dust only
             cls.wps_pixie = True
+            cls.wps_nullping = False
             cls.wps_pin = False
             Color.pl('{+} {C}option:{W} will {G}only{W} use {C}WPS Pixie-Dust ' +
                     'attack{W} (no {O}PIN{W}) on targets')
 
+        elif args.wps_no_nullpin:
+            # WPS NULL PIN only
+            cls.wps_pixie = False
+            cls.wps_nullpin = True
+            cls.wps_pin = False
+            Color.pl('{+} {C}option:{W} will {G}only{W} use {C}WPS NULL PIN ' +
+                    'attack{W} (no {O}PIN{W}) on targets')
+
         elif args.wps_no_pixie:
             # WPS PIN only
             cls.wps_pixie = False
+            cls.wps_nullpin = False
             cls.wps_pin = True
             Color.pl('{+} {C}option:{W} will {G}only{W} use {C}WPS PIN attack{W} ' +
                     '(no {O}Pixie-Dust{W}) on targets')
 
+
         if args.use_bully:
             from .tools.bully import Bully
             if not Bully.exists():
@@ -585,7 +598,7 @@ class Configuration(object):
         from .util.color import Color
 
         max_len = 20
-        for key in cls.__dict__.keys():
+        for key in list(cls.__dict__.keys()):
             max_len = max(max_len, len(key))
 
         result = Color.s('{W}%s  Value{W}\n' % 'cls Key'.ljust(max_len))
@@ -600,4 +613,4 @@ class Configuration(object):
 
 if __name__ == '__main__':
     Configuration.initialize(False)
-    print(Configuration.dump())
+    print((Configuration.dump()))
